import glob
import unittest
import os
import tempfile

from youtube2mp3.cli import Youtube2mp3
from youtube2mp3.options import options

TEST_ROOT = os.path.join(tempfile.gettempdir(), 'youtube2mp2')
if not os.path.isdir(TEST_ROOT):
    os.mkdir(TEST_ROOT)

setattr(options, 'directory', TEST_ROOT)



class TestCase(unittest.TestCase):
    def test_download(self):
        setattr(options, 'youtube_url', 'https://www.youtube.com/watch?v=XPudIeRotdI')
        y = Youtube2mp3()
        y.run()
        file_name = os.path.join(TEST_ROOT, 'EDX - Stay-XPudIeRotdI.mp3')
        self.assertEqual(True, os.path.isfile(file_name))

    def test_download_with_file(self):
        setattr(options, 'youtube_url', os.path.join(os.path.dirname(__file__), 'test.txt'))
        y = Youtube2mp3()
        y.run()
        files = glob.glob(TEST_ROOT + '/*.mp3')
        self.assertEqual(2, len(files))

    def tearDown(self) -> None:
        files = glob.glob(TEST_ROOT + '/*.mp3')
        for file in files:
            os.remove(file)

if __name__ == '__main__':
    unittest.main()



from codecs import open
from os.path import abspath, dirname, join
from setuptools import setup, find_packages
from youtube2mp3 import __version__, __author__

this_dir = abspath(dirname(__file__))
with open(join(this_dir, 'README.rst'), encoding='utf-8') as file:
    long_description = file.read()

setup(
    name='youtube2mp3',
    version=__version__,
    description='Commandline tool to convert youtube videos to tagged mp3 files',
    long_description=long_description,
    url='https://github.com/pfitzer/youtube2mp3.git',
    author=__author__,
    author_email='michael@mp-development.de',
    license='MIT',
    install_requires=['youtube-dl>=2020.11.1.1', 'mutagen>=1.45.1'],
    keywords='youtube mp3',
    packages=find_packages(),
    python_requires='~=3.6, <4',
    entry_points={
        'console_scripts': [
            'youtube2mp3=youtube2mp3.cli:main',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Multimedia :: Video :: Conversion'
    ]
)
